==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1UserInfoFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.kubernetes.client.fluent.Predicate;
import java.util.LinkedHashMap;

public interface V1beta1UserInfoFluent<A extends V1beta1UserInfoFluent<A>> extends Fluent<A>{


    public A addToExtra(String key,List<String> value);
    public A addToExtra(Map<String,List<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,List<String>> map);
    public Map<String,List<String>> getExtra();
    public A withExtra(Map<String,List<String>> extra);
    public Boolean hasExtra();
    public A addToGroups(int index,String item);
    public A setToGroups(int index,String item);
    public A addToGroups(String... items);
    public A addAllToGroups(Collection<String> items);
    public A removeFromGroups(String... items);
    public A removeAllFromGroups(Collection<String> items);
    public List<String> getGroups();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withGroups(List<String> groups);
    public A withGroups(String... groups);
    public Boolean hasGroups();
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public String getUsername();
    public A withUsername(String username);
    public Boolean hasUsername();



}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1UserInfoFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface V1beta1UserInfoFluent<A extends V1beta1UserInfoFluent<A>> extends Fluent<A>{


    public A addToExtra(String key,List<String> value);
    public A addToExtra(Map<String,List<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,List<String>> map);
    public Map<String,List<String>> getExtra();
    public A withExtra(Map<String,List<String>> extra);
    public Boolean hasExtra();
    public A addToGroups(int index,String item);
    public A setToGroups(int index,String item);
    public A addToGroups(String... items);
    public A addAllToGroups(Collection<String> items);
    public A removeFromGroups(String... items);
    public A removeAllFromGroups(Collection<String> items);
    public List<String> getGroups();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withGroups(List<String> groups);
    public A withGroups(String... groups);
    public Boolean hasGroups();
    public A addNewGroup(String arg1);
    public A addNewGroup(StringBuilder arg1);
    public A addNewGroup(StringBuffer arg1);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);
    public String getUsername();
    public A withUsername(String username);
    public Boolean hasUsername();
    public A withNewUsername(String arg1);
    public A withNewUsername(StringBuilder arg1);
    public A withNewUsername(StringBuffer arg1);



}
